HelpTryCatchFinally class

Help with Try Catch Finally

Finally

The finally clause runs whether or not an exception is thrown.

If there is a return statement in the try/catch block, the finally clause is run after the try/catch block operations and before the try/catch block return statement. If there is no catch clause which matches the Exception, the finally clause is run before propagating the Exception.

Constructors

HelpTryCatchFinally()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited